import { select, csv, 
        scaleLinear, max, 
        extent, axisLeft, 
        axisBottom, format } from 'd3';


const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  	const title = "Cars: Horsepower vs. Weight";
  	const xValue = d => d.horsepower;
  	const xAxisLabel = "Horse Power";
  
  	const yValue = d => d.weight;
  	const yAxisLabel = "Weight";
  
  	const margin = { left:120, top:60, right:40, bottom:88 };
  	const innerWidth = width - margin.left - margin.right;
  	const innerHeight = height - margin.top - margin.bottom;
  	const circleRadius = 10;
  
  	const xScale = scaleLinear()
    	.domain(extent(data, xValue))
    	.range([0, innerWidth])
    	.nice()
    ;
  
  	const yScale = scaleLinear()
    	.domain(extent(data, yValue))
    	.range([0, innerHeight])
    	.nice()
    	//.padding(0.7)	//no exist for linear scale
    ;
    
		//const yAxis = axisLeft(yScale);
  	
  
  	const g = svg.append('g')
    	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  	//const xAxisTickFormat = number => 
    //	format('.3s')(number).replace('G', 'B');
  
  	const xAxis = axisBottom(xScale)
    	//.tickFormat(xAxisTickFormat)
    	.tickSize(-innerHeight)
    	.tickPadding(12)
    	;
  
  	const yAxis = axisLeft(yScale)
    	.tickSize(-innerWidth)
    	.tickPadding(7)
    ;
    
  
  	//yAxis(g.append('g'));
  	const yAxisGrp = g.append('g').call(yAxis);
  			//.selectAll('.domain, .tick line')
  			
  	yAxisGrp.selectAll('.domain')
  				.remove()
  		;
  
    //problematic, cause graph to disappear
    yAxisGrp.append('text')
      .attr('class', 'axis-label')
      .attr('y', -85)
      .attr('x', -innerHeight/2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      //.attr('transform', 'rotate(-90)')
      .attr('text-anchor', 'middle')
      .text(yAxisLabel)
  		//.attr('transform', 'translate(-90)')
      ;
  
  	const xAixsGrp = g.append('g').call(xAxis)
  		.attr('transform', `translate(0, ${innerHeight})`);
  
  	xAixsGrp.select('.domain').remove();
  
  	xAixsGrp.append('text')
  		.attr('class', 'axis-label')
  		.attr('y', 60)
  		.attr('x', innerWidth/2)
  		.text(xAxisLabel)
  		//.style('fill', 'red')
  	;
  
		g.selectAll('circle')
  		.data(data)
  		.enter()
  		.append('circle')
  			.attr('cy', d => yScale(yValue(d)))
        .attr('cx', d => xScale(xValue(d)))
        .attr('r', circleRadius)
  			//how do I set x, y according to data?
  			
  	g.append('text')
  		.attr('class', 'chart-title')
  		.attr('y', -10)
      .text(title);
	};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
    render(data);
  });